@@ -25,6 +25,7 @@ from .log import get_logger
 from .transport import get_transport_cls, supports_librabbitmq
 from .utils import cached_property, retry_over_time, shufflecycle
 from .utils.compat import OrderedDict, LifoQueue as _LifoQueue, next
+from .utils.functional import promise
 from .utils.url import parse_url
 
 __all__ = ['Connection', 'ConnectionPool', 'ChannelPool']
@@ -857,7 +858,12 @@ class Resource(object):
                     try:
                         R = self.prepare(R)
                     except BaseException:
-                        self.release(R)
+                        if isinstance(R, promise):
+                            # no evaluated yet, just put it back
+                            self._resource.put_nowait(R)
+                        else:
+                            # evaluted so must try to release/close first.
+                            self.release(R)
                         raise
                     self._dirty.add(R)
                     break
@@ -996,7 +1002,7 @@ class ConnectionPool(Resource):
                     conn = self.new()
                     conn.connect()
                 else:
-                    conn = self.new
+                    conn = promise(self.new)
                 self._resource.put_nowait(conn)
 
     def prepare(self, resource):
@@ -1015,14 +1021,14 @@ class ChannelPool(Resource):
                                           preload=preload)
 
     def new(self):
-        return self.connection.channel
+        return promise(self.connection.channel)
 
     def setup(self):
         channel = self.new()
         if self.limit:
             for i in xrange(self.limit):
                 self._resource.put_nowait(
-                    i < self.preload and channel() or channel)
+                    i < self.preload and channel() or promise(channel))
 
     def prepare(self, channel):
         if callable(channel):
